from random import choice, randint


def generate_female_name(female_prefix, female_suffix, min=1, max=2):
    while True:
        try:
            num_prefix_syllables = randint(min, max)
            num_suffix_syllables = randint(min, max)
            if num_prefix_syllables == 0 and num_suffix_syllables == 0:
                raise ValueError
            
            if (num_prefix_syllables == 1 and num_suffix_syllables == 0):
                name = choice(female_prefix)
                return name.capitalize()

            name = ""
            for _ in range(num_prefix_syllables):
                syllable = choice(female_prefix)
                name += syllable
            
            for _ in range(num_suffix_syllables):
                syllable = choice(female_suffix)
                name += syllable
            
            return name.capitalize()
        except ValueError:
            continue


def generate_male_name(male_prefix, male_suffix, min=1, max=2):
    while True:
        try:
            num_prefix_syllables = randint(min, max)
            num_suffix_syllables = randint(min, max)
            if num_prefix_syllables == 0 and num_suffix_syllables == 0:
                raise ValueError
            
            if (num_prefix_syllables == 1 and num_suffix_syllables == 0):
                name = choice(male_prefix)
                return name.capitalize()

            name = ""
            for _ in range(num_prefix_syllables):
                syllable = choice(male_prefix)
                name += syllable
            
            for _ in range(num_suffix_syllables):
                syllable = choice(male_suffix)
                name += syllable
            
            return name.capitalize()
        except ValueError:
            continue


def generate_surname(surname_syllables, min=1, max=3):
    num_syllables = randint(min, max)
    synth_surname = ""
    for _ in range(num_syllables):
        syllable = choice(surname_syllables)
        synth_surname += syllable

    return synth_surname.capitalize()


def generate_surname_less(surname_prefix, surname_suffix):
    synth_surname = ""
    syllable_prefix = choice(surname_prefix)
    syllable_suffix = choice(surname_suffix)
    synth_surname += syllable_prefix + syllable_suffix
    
    return synth_surname.capitalize()


def remove_duplicates(female_names, male_names, surnames):
    # Remove duplicates
    female = list(set(female_names))
    male = list(set(male_names))
    surname = list(set(surnames))

    # Sort alphabetically
    female.sort()
    male.sort()
    surname.sort()

    all_lists = {
        'female': female,
        'male': male,
        'surname': surname
    }
    
    return all_lists


from random import choice

female_names = [
    'Abigail', 'Ada', 'Adaline', 'Adelaide', 'Adeline', 'Agatha', 'Agnes',
    'Alberta', 'Alexandria', 'Althea', 'Amaryllis', 'Amelia', 'Antoinette',
    'Arabella', 'Astrid', 'Augusta', 'Aurelia', 'Aurora', 'Beatrice', 'Bianca',
    'Calista', 'Camilla', 'Cecilia', 'Celeste', 'Charlotte', 'Clara', 'Clarissa',
    'Clementine', 'Constance', 'Cordelia', 'Corinne', 'Dahlia', 'Daisy', 'Daphne',
    'Delilah', 'Dorothea', 'Edith', 'Eleanor', 'Eliza', 'Eloise', 'Emmeline',
    'Estella', 'Eugenia', 'Euphemia', 'Evangeline', 'Faye', 'Felicity', 'Fern',
    'Fiona', 'Florence', 'Freya', 'Geneva', 'Genevieve', 'Georgiana', 'Ginevra',
    'Giselle', 'Guinevere', 'Gwendolyn', 'Harriet', 'Hazel', 'Helena', 'Henrietta',
    'Hermione', 'Honoria', 'Imelda', 'Imogen', 'Ingrid', 'Iris', 'Isadora', 'Ivy',
    'Josephine', 'Juniper', 'Lavinia', 'Lenora', 'Lilith', 'Lillian', 'Lorelei',
    'Lucinda', 'Lydia', 'Mabel', 'Maeve', 'Magnolia', 'Marceline', 'Mariana',
    'Marigold', 'Matilda', 'Millicent', 'Minerva', 'Mirabelle', 'Nora', 'Octavia',
    'Odette', 'Olive', 'Opal', 'Ophelia', 'Penelope', 'Persephone', 'Philomena',
    'Primrose', 'Prudence', 'Rosalind', 'Rosamund', 'Rowena', 'Scarlett', 'Seraphina',
    'Sophronia', 'Sylvia', 'Tabitha', 'Temperance', 'Theodora', 'Valentina', 'Veronica',
    'Victoria', 'Viola', 'Vivienne', 'Wilhelmina', 'Winifred', 'Winona', 'Zara', 'Zelda',
    'Zephyrine', 'Zinnia'
]

male_names = [
    'Alaric', 'Alastair', 'Algernon', 'Ambrose', 'Archibald', 'Atticus', 'Augustus',
    'Balthazar', 'Barnaby', 'Bartholomew', 'Basil', 'Benedict', 'Caspian', 'Cassius',
    'Cecil', 'Cedric', 'Clarence', 'Cornelius', 'Crispin', 'Cyrus', 'Dashiell', 'Dexter',
    'Dominic', 'Dorian', 'Edgar', 'Edmund', 'Edric', 'Edwin', 'Elias', 'Ephraim', 'Everard',
    'Ezekiel', 'Felix', 'Ferdinand', 'Finnegan', 'Fitzwilliam', 'Fletcher', 'Gabriel',
    'Gideon', 'Godfrey', 'Gulliver', 'Hamilton', 'Harrison', 'Hawthorne', 'Horatio', 'Hugo',
    'Humphrey', 'Ignatius', 'Isidore', 'Jareth', 'Jasper', 'Jeremiah', 'Jonathan', 'Kendrick',
    'Kingsley', 'Klaus', 'Lancaster', 'Lancelot', 'Lazarus', 'Leopold', 'Lysander', 'Maverick',
    'Maximilian', 'Maximus', 'Milo', 'Montgomery', 'Mortimer', 'Nathaniel', 'Nero', 'Neville',
    'Nigel', 'Oberon', 'Octavius', 'Oliver', 'Orlando', 'Orson', 'Percival', 'Peregrine', 'Phineas',
    'Quentin', 'Quilliam', 'Quincy', 'Rafferty', 'Randolph', 'Raphael', 'Reginald', 'Rufus', 'Rupert',
    'Rutherford', 'Salvador', 'Seamus', 'Sebastian', 'Silas', 'Simeon', 'Sullivan', 'Thaddeus',
    'Thelonious', 'Theodore', 'Tobias', 'Tristan', 'Ulrich', 'Ulysses', 'Upton', 'Uriah',
    'Valentine', 'Vesper', 'Victor', 'Virgil', 'Walter', 'Wellington', 'Wesley', 'Wilbur',
    'Wilfred', 'Winston', 'Wolfgang', 'Xander', 'Xavier', 'Yancy', 'Yardley', 'Yorick', 'Zachariah',
    'Zacharias', 'Zebediah', 'Zephyr', 'Zephyrus'
]

surnames = [
    "Ainsworth",
    "Aldington",
    "Aldridge",
    "Archer",
    "Ashburton",
    "Ashcroft",
    "Ashford",
    "Beauchamp",
    "Beaumont",
    "Blackburn",
    "Blackwood",
    "Blakeley",
    "Bradford",
    "Bradshaw",
    "Bromley",
    "Bromsgrove",
    "Buckingham",
    "Carrington",
    "Chadwick",
    "Chamberlain",
    "Chandler",
    "Channing",
    "Charleston",
    "Charlton",
    "Chatham",
    "Chesney",
    "Clarendon",
    "Copperfield",
    "Cromwell",
    "Cunningham",
    "Darcy",
    "Davenport",
    "Drakeford",
    "Dunhill",
    "Dunstan",
    "Ellington",
    "Ellsworth",
    "Everhart",
    "Fairchild",
    "Fairfax",
    "Farnsworth",
    "Fitzgerald",
    "Fitzroy",
    "Fitzwilliam",
    "Grantham",
    "Graves",
    "Gresham",
    "Griffith",
    "Grimm",
    "Hadley",
    "Hammersmith",
    "Hampton",
    "Hargreaves",
    "Harrington",
    "Hartford",
    "Hawkesworth",
    "Hawkswood",
    "Hawksworth",
    "Hawthorne",
    "Hazelwood",
    "Hemingway",
    "Holland",
    "Holliday",
    "Hollingsworth",
    "Holmes",
    "Huntington",
    "Huxley",
    "Huxtable",
    "Kensington",
    "Kingsford",
    "Kingsley",
    "Lancashire",
    "Lancaster",
    "Langdon",
    "Langley",
    "Linden",
    "Livingston",
    "Lockwood",
    "Maitland",
    "Montague",
    "Montgomery",
    "Parrish",
    "Pemberley",
    "Pembroke",
    "Pendleton",
    "Radburn",
    "Radcliffe",
    "Radley",
    "Ramsey",
    "Rutherford",
    "Standish",
    "Stanhope",
    "Stratford",
    "Stratton",
    "Sunderland",
    "Sutherland",
    "Templeton",
    "Tennyson",
    "Thackeray",
    "Thornfield",
    "Wadsworth",
    "Warrick",
    "Warrington",
    "Waverly",
    "Wellington",
    "Wentworth",
    "Weston",
    "Wetherby",
    "Whitfield",
    "Whitlock",
    "Whittington",
    "Whitworth",
    "Wilberforce",
    "Winchester",
    "Windsor",
    "Winslow",
    "Winthorpe",
    "Winthrop",
    "Witherspoon",
    "Wolcott",
    "Worthington",
    "Wycliffe",
]

female = choice(female_names)
male = choice(male_names)
surname = choice(surnames)


from .supportive_functions import generate_female_name, generate_male_name, generate_surname


female_suffix = [
    "a", "bel", "cia", "da", "el", "fae", "gwyn", "hia", "i", "ja", "ka", "la", "ma", "na", "ora", "pa",
    "qua", "ra", "sa", "ta", "ula", "va", "wa", "xa", "ya", "za",
    "belle", "cey", "dine", "elle", "finn", "grace", "hira", "ira", "jade", "kara", "lynn", "mara", "nora",
    "opal", "phina", "quella", "rina", "sera", "tia", "una", "vella", "wren", "xina", "yara", "zara"
]

male_prefix = [
    "ach", "an", "ar", "bal", "be", "bel", "bran", "cal", "cor", "dar", "de", "del", "dra", "er",
    "fis", "gal", "gar", "ha", "he", "hir", "il", "ja", "kel", "kor", "lar", "le", "li", "ma", "mar",
    "na", "nor", "ol", "on", "pa", "pel", "per", "qua", "ra", "ran", "rel", "ro", "sa", "sar", "sel",
    "tar", "te", "ti", "to", "ur", "va", "var", "vel", "ver", "wa", "wal", "ya", "yar", "zel"
]

male_suffix = [
    "ad", "al", "an", "ar", "as", "av", "don", "dor", "el", "en", "er", "es", "gan", "har", "hor",
    "ian", "ic", "id", "il", "in", "is", "kan", "kar", "kas", "lak", "las", "lin", "lon", "mar", "mon",
    "nan", "nar", "nas", "non", "or", "rad", "ran", "ras", "rik", "ron", "sal", "san", "tas", "tar",
    "tin", "ton", "ur", "us", "van", "var", "ver", "von", "war", "won", "yas", "zan", "zen", "zon"
]

female_prefix = [
    "acht", "bry", "cali", "dara", "ell", "fay", "gwen", "hela", "is", "jen", "kala", "lara", "morga",
    "nala", "orla", "pae", "quen", "rae", "sab", "tara", "ulan", "vay", "wyn", "xan", "yara", "zara",
    "bel", "cara", "dela", "ella", "fin", "grace", "hira", "ira", "jenna", "kira", "luna", "maia", "nira",
    "opal", "pippa", "quela", "rona", "saffron", "tessa", "ula", "vanna", "willa", "xara", "yuna", "zella"
]

surname_syllables =  [
    'al', 'an', 'ar', 'ark', 'as', 'ash', 'ba', 'bar', 'be', 'bel', 'car', 'cas', 'cor','da', 'dal', 'dar',
    'de', 'del', 'di', 'don', 'dor', 'el', 'en', 'er', 'es', 'fal', 'far', 'fi', 'gal', 'gar', 'har', 'ho',
    'ian', 'ik', 'il', 'in', 'is', 'ja', 'jar', 'kal', 'kar', 'kas', 'ken', 'kor', 'lar', 'li', 'lon', 'ma',
    'mal', 'mar', 'mas', 'mon', 'na', 'nal', 'nar', 'ni', 'no', 'on', 'or', 'pa', 'par', 'per', 'qu', 'ra',
    'ral', 'ran', 'ri', 'ril', 'ro', 'ron', 'sa', 'sal', 'sha', 'si', 'st', 'ta', 'tar', 'th', 'thal', 'thar',
    'thon', 'ti', 'tin', 'tor', 'un', 'ur', 'va', 'val', 'var', 'ver', 'von', 'wan', 'war', 'wen', 'win', 'ya',
    'yar', 'yen', 'yin', 'yor', 'za', 'zan', 'zar'
]


female = generate_female_name(female_prefix, female_suffix, min=0, max=2)
male = generate_male_name(male_prefix, male_suffix, min=0, max=2)
surname = generate_surname(surname_syllables, min=2, max=3)